
## Ai

| Module | Description |
| ------ | ----------- |
| [PyTorch](https://pytorch.org/) | Tensors and Dynamic neural networks in Python with strong GPU acceleration. PyTorch is a deep learning framework that puts Python first. |

## Base

| Module | Description |
| ------ | ----------- |
| [Python](https://python.org/) | Python is a programming language that lets you work more quickly and integrate your systems more effectively. |
| [sysbench](https://github.com/akopytov/sysbench) | sysbench is a scriptable multi-threaded benchmark tool based on LuaJIT. It is most frequently used for database benchmarks, but can also be used to create arbitrarily complex workloads that do not involve a database server. |

## Bio

| Module | Description |
| ------ | ----------- |
| [AlphaFold](https://deepmind.com/research/case-studies/alphafold) | AlphaFold can predict protein structures with atomic accuracy even where no similar structure is known |
| [Biopython](http://www.biopython.org) | Biopython is a set of freely available tools for biological computation written in Python by an international team of developers. It is a distributed collaborative effort to develop Python libraries and applications which address the needs of current and future work in bioinformatics. |
| [BWA](http://bio-bwa.sourceforge.net/) | Burrows-Wheeler Aligner (BWA) is an efficient program that aligns relatively short nucleotide sequences against a long reference sequence such as the human genome. |
| [Cgicc](https://www.gnu.org/software/cgicc/index.html) | GNU Cgicc is an ANSI C++ compliant class library that greatly simplifies the creation of CGI applications for the World Wide Web |
| [Cordax](https://cordax.switchlab.org/) | CORDAX is an aggregation propensity predictor based on predicted packing energies. |
| [ctffind](https://grigoriefflab.umassmed.edu/ctffind4) | Program for finding CTFs of electron micrographs. |
| [FastCGI](https://github.com/FastCGI-Archives/fcgi2) | A High-Performance Web Server Interface |
| [FoldX](http://http://foldxsuite.crg.eu/) | FoldX is used to provide a fast and quantitative estimation of the importance of the interactions contributing to the stability of proteins and protein complexes. |
| [GATK](https://www.broadinstitute.org/gatk/) | The Genome Analysis Toolkit or GATK is a software package developed at the Broad Institute to analyse next-generation resequencing data. The toolkit offers a wide variety of tools, with a primary focus on variant discovery and genotyping as well as strong emphasis on data quality assurance. Its robust architecture, powerful processing engine and high-performance computing features make it capable of taking on projects of any size. |
| [GROMACS](http://www.gromacs.org) | GROMACS is a versatile package to perform molecular dynamics, i.e. simulate the Newtonian equations of motion for systems with hundreds to millions of particles. |
| [HH-suite](https://github.com/soedinglab/hh-suite) | The HH-suite is an open-source software package for sensitive protein sequence searching based on the pairwise alignment of hidden Markov models (HMMs). |
| [HMMER](http://hmmer.org/) | HMMER is used for searching sequence databases for homologs of protein sequences, and for making protein sequence alignments. It implements methods using probabilistic models called profile hidden Markov models (profile HMMs). Compared to BLAST, FASTA, and other sequence alignment and database search tools based on older scoring methodology, HMMER aims to be significantly more accurate and more able to detect remote homologs because of the strength of its underlying mathematical models. In the past, this strength came at significant computational expense, but in the new HMMER3 project, HMMER is now essentially as fast as BLAST. |
| [Kalign](https://github.com/TimoLassmann/kalign) | Kalign is a fast multiple sequence alignment program for biological sequences. |
| [mrcfile](https://github.com/ccpem/mrcfile) | mrcfile is a Python implementation of the MRC2014 file format, which is used in structural biology to store image and volume data. It allows MRC files to be created and opened easily using a very simple API, which exposes the file’s header and data as numpy arrays. The code runs in Python 2 and 3 and is fully unit-tested. This library aims to allow users and developers to read and write standard- compliant MRC files in Python as easily as possible, and with no dependencies on any compiled libraries except numpy. You can use it interactively to inspect files, correct headers and so on, or in scripts and larger software packages to provide basic MRC file I/O functions. |
| [OpenMM](https://openmm.org) | OpenMM is a toolkit for molecular simulation. |
| [picard](https://broadinstitute.github.io/picard/) | A set of tools (in Java) for working with next generation sequencing data in the BAM format. |
| [RELION](http://www2.mrc-lmb.cam.ac.uk/relion/index.php/Main_Page) | RELION (for REgularised LIkelihood OptimisatioN, pronounce rely-on) is a stand-alone computer program that employs an empirical Bayesian approach to refinement of (multiple) 3D reconstructions or 2D class averages in electron cryo-microscopy (cryo-EM). |
| [Salmon](https://github.com/COMBINE-lab/salmon) | Salmon is a wicked-fast program to produce a highly-accurate, transcript-level quantification estimates from RNA-seq data. |
| [snpEff](https://pcingola.github.io/SnpEff/) | SnpEff is a variant annotation and effect prediction tool. It annotates and predicts the effects of genetic variants (such as amino acid changes). |
| Tango | N/A |
| Waltz | N/A |

## Cae

| Module | Description |
| ------ | ----------- |
| [DualSPHysics](https://dual.sphysics.org/) | DualSPHysics is based on the Smoothed Particle Hydrodynamics model named SPHysics. The code is developed to study free-surface flow phenomena where Eulerian methods can be difficult to apply, such as waves or impact of dam-breaks on off-shore structures. DualSPHysics is a set of C++, CUDA and Java codes designed to deal with real-life engineering problems. |
| [OpenFOAM](https://www.openfoam.com/) | OpenFOAM is a free, open source CFD software package. OpenFOAM has an extensive range of features to solve anything from complex fluid flows involving chemical reactions, turbulence and heat transfer, to solid dynamics and electromagnetics. |
| [STAR-CCM+](https://mdx.plm.automation.siemens.com/star-ccm-plus) | STAR-CCM+ is a multiphysics computational fluid dynamics (CFD) software for the simulation of products operating under real-world conditions. |

## Chem

| Module | Description |
| ------ | ----------- |
| [ABCluster](http://zhjun-sci.com/home-EN.php) | ABCluster a program for the global optimization of chemical cluster structures. |
| [ABINIT](https://www.abinit.org/) | ABINIT is a package whose main program allows one to find the total energy, charge density and electronic structure of systems made of electrons and nuclei (molecules and periodic solids) within Density Functional Theory (DFT), using pseudopotentials and a planewave or wavelet basis. |
| [Amber](http://ambermd.org/amber.html) | Amber (originally Assisted Model Building with Energy Refinement) is software for performing molecular dynamics and structure prediction. |
| [ASE](https://wiki.fysik.dtu.dk/ase) | ASE is a python package providing an open source Atomic Simulation Environment in the Python scripting language. From version 3.20.1 we also include the ase-ext package, it contains optional reimplementations in C of functions in ASE. ASE uses it automatically when installed. |
| [BEEF](http://suncat.stanford.edu/facility/software/functional) | BEEF is a library-based implementation of the Bayesian Error Estimation Functional, suitable for linking against by Fortran- or C-based DFT codes. A description of BEEF can be found at http://dx.doi.org/10.1103/PhysRevB.85.235149. |
| [CheMPS2](https://github.com/SebWouters/CheMPS2) | CheMPS2 is a scientific library which contains a spin-adapted implementation of the density matrix renormalization group (DMRG) for ab initio quantum chemistry. |
| [CoordgenLibs](https://github.com/schrodinger/coordgenlibs) | Schrodinger-developed 2D Coordinate Generation |
| [CP2K](https://www.cp2k.org/) | CP2K is a freely available (GPL) program, written in Fortran 95, to perform atomistic and molecular simulations of solid state, liquid, molecular and biological systems. It provides a general framework for different methods such as e.g. density functional theory (DFT) using a mixed Gaussian and plane waves approach (GPW), and classical pair and many-body potentials. |
| [CPPE](https://github.com/maxscheurer/cppe) | CPPE is an open-source, light-weight C++ and Python library for Polarizable Embedding (PE)1,2 calculations. It provides an easy-to-use API to implement PE for ground-state self-consistent field (SCF) calculations and post-SCF methods. A convenient Python interface is also available. |
| [cppe](https://github.com/maxscheurer/cppe) | CPPE is an open-source, light-weight C++ and Python library for Polarizable Embedding (PE)1,2 calculations. It provides an easy-to-use API to implement PE for ground-state self-consistent field (SCF) calculations and post-SCF methods. A convenient Python interface is also available. |
| [DFT-D3](http://www.thch.uni-bonn.de/tc/index.php?section=downloads&subsection=DFT-D3&lang=english) | DFT-D3 implements a dispersion correction for density functionals, Hartree-Fock and semi-empirical quantum chemical methods. |
| [DFT-D4](https://www.chemie.uni-bonn.de/pctc/mulliken-center/software/dftd4) | Generally Applicable Atomic-Charge Dependent London Dispersion Correction. |
| [dftd3-lib](https://github.com/dftbplus/dftd3-lib) | This is a repackaged version of the DFTD3 program by S. Grimme and his coworkers. The original program (V3.1 Rev 1) was downloaded at 2016-04-03. It has been converted to free format and encapsulated into modules. |
| [Dice](https://github.com/sanshar/Dice) | Dice contains code for performing SHCI, VMC, GFMC, DMC, FCIQMC, stochastic MRCI and SC-NEVPT2, and AFQMC calculations with a focus on ab initio systems. |
| [dkh](https://github.com/psi4/dkh) | Wolf, Reiher, and Hess's Douglas-Kroll-Hess relativistic correction at 2nd–4th order (http://www.reiher.ethz.ch/software/dkh-x2c.html) wrapped in CMake for Psi4 (https://github.com/psi4/psi4) |
| [gau2grid](https://github.com/dgasmith/gau2grid) | A collocation code for computing gaussians on a grid of the form: out_Lp = x^l y^m z^n \sum_i coeff_i e^(exponent_i * (|center - p|)^2) Where the returned matrix dimension are the angular momentum (L) by number of requested points (p). |
| [gdma](https://github.com/psi4/gdma) | Anthony Stone's GDMA (http://www-stone.ch.cam.ac.uk/programs.html) wrapped in CMake for Psi4 (https://github.com/psi4/psi4) |
